import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class CloudSchedulerResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class JobsResource(googleapiclient.discovery.Resource):
                def create(
                    self, *, parent: str, body: Job = ..., **kwargs: typing.Any
                ) -> JobHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(self, *, name: str, **kwargs: typing.Any) -> JobHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListJobsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListJobsResponseHttpRequest,
                    previous_response: ListJobsResponse,
                ) -> ListJobsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: Job = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> JobHttpRequest: ...
                def pause(
                    self,
                    *,
                    name: str,
                    body: PauseJobRequest = ...,
                    **kwargs: typing.Any
                ) -> JobHttpRequest: ...
                def resume(
                    self,
                    *,
                    name: str,
                    body: ResumeJobRequest = ...,
                    **kwargs: typing.Any
                ) -> JobHttpRequest: ...
                def run(
                    self, *, name: str, body: RunJobRequest = ..., **kwargs: typing.Any
                ) -> JobHttpRequest: ...

            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> LocationHttpRequest: ...
            def list(
                self,
                *,
                name: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListLocationsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListLocationsResponseHttpRequest,
                previous_response: ListLocationsResponse,
            ) -> ListLocationsResponseHttpRequest | None: ...
            def jobs(self) -> JobsResource: ...

        def locations(self) -> LocationsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class JobHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Job: ...

@typing.type_check_only
class ListJobsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListJobsResponse: ...

@typing.type_check_only
class ListLocationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListLocationsResponse: ...

@typing.type_check_only
class LocationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Location: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class WebRiskResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class HashesResource(googleapiclient.discovery.Resource):
        def search(
            self,
            *,
            hashPrefix: str = ...,
            threatTypes: typing_extensions.Literal[
                "THREAT_TYPE_UNSPECIFIED",
                "MALWARE",
                "SOCIAL_ENGINEERING",
                "UNWANTED_SOFTWARE",
                "SOCIAL_ENGINEERING_EXTENDED_COVERAGE",
            ]
            | _list[
                typing_extensions.Literal[
                    "THREAT_TYPE_UNSPECIFIED",
                    "MALWARE",
                    "SOCIAL_ENGINEERING",
                    "UNWANTED_SOFTWARE",
                    "SOCIAL_ENGINEERING_EXTENDED_COVERAGE",
                ]
            ] = ...,
            **kwargs: typing.Any
        ) -> GoogleCloudWebriskV1SearchHashesResponseHttpRequest: ...

    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class OperationsResource(googleapiclient.discovery.Resource):
            def cancel(
                self,
                *,
                name: str,
                body: GoogleLongrunningCancelOperationRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleProtobufEmptyHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleProtobufEmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleLongrunningOperationHttpRequest: ...
            def list(
                self,
                *,
                name: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> GoogleLongrunningListOperationsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GoogleLongrunningListOperationsResponseHttpRequest,
                previous_response: GoogleLongrunningListOperationsResponse,
            ) -> GoogleLongrunningListOperationsResponseHttpRequest | None: ...

        @typing.type_check_only
        class SubmissionsResource(googleapiclient.discovery.Resource):
            def create(
                self,
                *,
                parent: str,
                body: GoogleCloudWebriskV1Submission = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudWebriskV1SubmissionHttpRequest: ...

        @typing.type_check_only
        class UrisResource(googleapiclient.discovery.Resource):
            def submit(
                self,
                *,
                parent: str,
                body: GoogleCloudWebriskV1SubmitUriRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleLongrunningOperationHttpRequest: ...

        def operations(self) -> OperationsResource: ...
        def submissions(self) -> SubmissionsResource: ...
        def uris(self) -> UrisResource: ...

    @typing.type_check_only
    class ThreatListsResource(googleapiclient.discovery.Resource):
        def computeDiff(
            self,
            *,
            constraints_maxDatabaseEntries: int = ...,
            constraints_maxDiffEntries: int = ...,
            constraints_supportedCompressions: typing_extensions.Literal[
                "COMPRESSION_TYPE_UNSPECIFIED", "RAW", "RICE"
            ]
            | _list[
                typing_extensions.Literal["COMPRESSION_TYPE_UNSPECIFIED", "RAW", "RICE"]
            ] = ...,
            threatType: typing_extensions.Literal[
                "THREAT_TYPE_UNSPECIFIED",
                "MALWARE",
                "SOCIAL_ENGINEERING",
                "UNWANTED_SOFTWARE",
                "SOCIAL_ENGINEERING_EXTENDED_COVERAGE",
            ] = ...,
            versionToken: str = ...,
            **kwargs: typing.Any
        ) -> GoogleCloudWebriskV1ComputeThreatListDiffResponseHttpRequest: ...

    @typing.type_check_only
    class UrisResource(googleapiclient.discovery.Resource):
        def search(
            self,
            *,
            threatTypes: typing_extensions.Literal[
                "THREAT_TYPE_UNSPECIFIED",
                "MALWARE",
                "SOCIAL_ENGINEERING",
                "UNWANTED_SOFTWARE",
                "SOCIAL_ENGINEERING_EXTENDED_COVERAGE",
            ]
            | _list[
                typing_extensions.Literal[
                    "THREAT_TYPE_UNSPECIFIED",
                    "MALWARE",
                    "SOCIAL_ENGINEERING",
                    "UNWANTED_SOFTWARE",
                    "SOCIAL_ENGINEERING_EXTENDED_COVERAGE",
                ]
            ] = ...,
            uri: str = ...,
            **kwargs: typing.Any
        ) -> GoogleCloudWebriskV1SearchUrisResponseHttpRequest: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def hashes(self) -> HashesResource: ...
    def projects(self) -> ProjectsResource: ...
    def threatLists(self) -> ThreatListsResource: ...
    def uris(self) -> UrisResource: ...

@typing.type_check_only
class GoogleCloudWebriskV1ComputeThreatListDiffResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudWebriskV1ComputeThreatListDiffResponse: ...

@typing.type_check_only
class GoogleCloudWebriskV1SearchHashesResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudWebriskV1SearchHashesResponse: ...

@typing.type_check_only
class GoogleCloudWebriskV1SearchUrisResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudWebriskV1SearchUrisResponse: ...

@typing.type_check_only
class GoogleCloudWebriskV1SubmissionHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudWebriskV1Submission: ...

@typing.type_check_only
class GoogleLongrunningListOperationsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleLongrunningListOperationsResponse: ...

@typing.type_check_only
class GoogleLongrunningOperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleLongrunningOperation: ...

@typing.type_check_only
class GoogleProtobufEmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleProtobufEmpty: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Accessibility(typing_extensions.TypedDict, total=False):
    mobilityAccessible: bool
    mobilityAccessibleElevator: bool
    mobilityAccessibleElevatorException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    mobilityAccessibleException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    mobilityAccessibleParking: bool
    mobilityAccessibleParkingException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    mobilityAccessiblePool: bool
    mobilityAccessiblePoolException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]

@typing.type_check_only
class Activities(typing_extensions.TypedDict, total=False):
    beachAccess: bool
    beachAccessException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    beachFront: bool
    beachFrontException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    bicycleRental: bool
    bicycleRentalException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    boutiqueStores: bool
    boutiqueStoresException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    casino: bool
    casinoException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    freeBicycleRental: bool
    freeBicycleRentalException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    freeWatercraftRental: bool
    freeWatercraftRentalException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    gameRoom: bool
    gameRoomException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    golf: bool
    golfException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    horsebackRiding: bool
    horsebackRidingException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    nightclub: bool
    nightclubException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    privateBeach: bool
    privateBeachException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    scuba: bool
    scubaException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    snorkeling: bool
    snorkelingException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    tennis: bool
    tennisException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    waterSkiing: bool
    waterSkiingException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    watercraftRental: bool
    watercraftRentalException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]

@typing.type_check_only
class Business(typing_extensions.TypedDict, total=False):
    businessCenter: bool
    businessCenterException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    meetingRooms: bool
    meetingRoomsCount: int
    meetingRoomsCountException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    meetingRoomsException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]

@typing.type_check_only
class Connectivity(typing_extensions.TypedDict, total=False):
    freeWifi: bool
    freeWifiException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    publicAreaWifiAvailable: bool
    publicAreaWifiAvailableException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    publicInternetTerminal: bool
    publicInternetTerminalException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    wifiAvailable: bool
    wifiAvailableException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]

@typing.type_check_only
class EcoCertification(typing_extensions.TypedDict, total=False):
    awarded: bool
    awardedException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    ecoCertificate: typing_extensions.Literal[
        "ECO_CERTIFICATE_UNSPECIFIED",
        "ISO14001",
        "ISO50001",
        "ASIAN_ECOTOURISM",
        "BIOSPHERE_RESPOSNIBLE_TOURISM",
        "BUREAU_VERITAS",
        "CONTROL_UNION",
        "EARTHCHECK",
        "ECO_CERTIFICATION_MALTA",
        "ECOTOURISM_AUSTRALIAS_ECO",
        "GREAT_GREEN_DEAL",
        "GREEN_GLOBE",
        "GREEN_GROWTH2050",
        "GREEN_KEY",
        "GREEN_KEY_ECO_RATING",
        "GREEN_SEAL",
        "GREEN_STAR",
        "GREEN_TOURISM_ACTIVE",
        "HILTON_LIGHTSTAY",
        "HOSTELLING_INTERNATIONALS_QUALITY_AND_SUSTAINABILITY",
        "HOTELES_MAS_VERDES",
        "NORDIC_SWAN_ECOLABEL",
        "PREFERRED_BY_NATURE_SUSTAINABLE_TOURISM",
        "SUSTAINABLE_TRAVEL_IRELAND",
        "TOF_TIGERS_INITITIVES_PUG",
        "TRAVELIFE",
        "UNITED_CERTIFICATION_SYSTEMS_LIMITED",
        "VIREO_SRL",
    ]

@typing.type_check_only
class EnergyEfficiency(typing_extensions.TypedDict, total=False):
    carbonFreeEnergySources: bool
    carbonFreeEnergySourcesException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    energyConservationProgram: bool
    energyConservationProgramException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    energyEfficientHeatingAndCoolingSystems: bool
    energyEfficientHeatingAndCoolingSystemsException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    energyEfficientLighting: bool
    energyEfficientLightingException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    energySavingThermostats: bool
    energySavingThermostatsException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    greenBuildingDesign: bool
    greenBuildingDesignException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    independentOrganizationAuditsEnergyUse: bool
    independentOrganizationAuditsEnergyUseException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]

@typing.type_check_only
class EnhancedCleaning(typing_extensions.TypedDict, total=False):
    commercialGradeDisinfectantCleaning: bool
    commercialGradeDisinfectantCleaningException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    commonAreasEnhancedCleaning: bool
    commonAreasEnhancedCleaningException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    employeesTrainedCleaningProcedures: bool
    employeesTrainedCleaningProceduresException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    employeesTrainedThoroughHandWashing: bool
    employeesTrainedThoroughHandWashingException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    employeesWearProtectiveEquipment: bool
    employeesWearProtectiveEquipmentException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    guestRoomsEnhancedCleaning: bool
    guestRoomsEnhancedCleaningException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]

@typing.type_check_only
class Families(typing_extensions.TypedDict, total=False):
    babysitting: bool
    babysittingException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    kidsActivities: bool
    kidsActivitiesException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    kidsClub: bool
    kidsClubException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]

@typing.type_check_only
class FoodAndDrink(typing_extensions.TypedDict, total=False):
    bar: bool
    barException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    breakfastAvailable: bool
    breakfastAvailableException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    breakfastBuffet: bool
    breakfastBuffetException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    buffet: bool
    buffetException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    dinnerBuffet: bool
    dinnerBuffetException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    freeBreakfast: bool
    freeBreakfastException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    restaurant: bool
    restaurantException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    restaurantsCount: int
    restaurantsCountException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    roomService: bool
    roomServiceException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    tableService: bool
    tableServiceException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    twentyFourHourRoomService: bool
    twentyFourHourRoomServiceException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    vendingMachine: bool
    vendingMachineException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]

@typing.type_check_only
class GetGoogleUpdatedLodgingResponse(typing_extensions.TypedDict, total=False):
    diffMask: str
    lodging: Lodging

@typing.type_check_only
class GuestUnitFeatures(typing_extensions.TypedDict, total=False):
    bungalowOrVilla: bool
    bungalowOrVillaException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    connectingUnitAvailable: bool
    connectingUnitAvailableException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    executiveFloor: bool
    executiveFloorException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    maxAdultOccupantsCount: int
    maxAdultOccupantsCountException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    maxChildOccupantsCount: int
    maxChildOccupantsCountException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    maxOccupantsCount: int
    maxOccupantsCountException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    privateHome: bool
    privateHomeException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    suite: bool
    suiteException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    tier: typing_extensions.Literal[
        "UNIT_TIER_UNSPECIFIED", "STANDARD_UNIT", "DELUXE_UNIT"
    ]
    tierException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    totalLivingAreas: LivingArea
    views: ViewsFromUnit

@typing.type_check_only
class GuestUnitType(typing_extensions.TypedDict, total=False):
    codes: _list[str]
    features: GuestUnitFeatures
    label: str

@typing.type_check_only
class HealthAndSafety(typing_extensions.TypedDict, total=False):
    enhancedCleaning: EnhancedCleaning
    increasedFoodSafety: IncreasedFoodSafety
    minimizedContact: MinimizedContact
    personalProtection: PersonalProtection
    physicalDistancing: PhysicalDistancing

@typing.type_check_only
class Housekeeping(typing_extensions.TypedDict, total=False):
    dailyHousekeeping: bool
    dailyHousekeepingException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    housekeepingAvailable: bool
    housekeepingAvailableException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    turndownService: bool
    turndownServiceException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]

@typing.type_check_only
class IncreasedFoodSafety(typing_extensions.TypedDict, total=False):
    diningAreasAdditionalSanitation: bool
    diningAreasAdditionalSanitationException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    disposableFlatware: bool
    disposableFlatwareException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    foodPreparationAndServingAdditionalSafety: bool
    foodPreparationAndServingAdditionalSafetyException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    individualPackagedMeals: bool
    individualPackagedMealsException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    singleUseFoodMenus: bool
    singleUseFoodMenusException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]

@typing.type_check_only
class LanguageSpoken(typing_extensions.TypedDict, total=False):
    languageCode: str
    spoken: bool
    spokenException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]

@typing.type_check_only
class LivingArea(typing_extensions.TypedDict, total=False):
    accessibility: LivingAreaAccessibility
    eating: LivingAreaEating
    features: LivingAreaFeatures
    layout: LivingAreaLayout
    sleeping: LivingAreaSleeping

@typing.type_check_only
class LivingAreaAccessibility(typing_extensions.TypedDict, total=False):
    adaCompliantUnit: bool
    adaCompliantUnitException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    hearingAccessibleDoorbell: bool
    hearingAccessibleDoorbellException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    hearingAccessibleFireAlarm: bool
    hearingAccessibleFireAlarmException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    hearingAccessibleUnit: bool
    hearingAccessibleUnitException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    mobilityAccessibleBathtub: bool
    mobilityAccessibleBathtubException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    mobilityAccessibleShower: bool
    mobilityAccessibleShowerException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    mobilityAccessibleToilet: bool
    mobilityAccessibleToiletException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    mobilityAccessibleUnit: bool
    mobilityAccessibleUnitException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]

@typing.type_check_only
class LivingAreaEating(typing_extensions.TypedDict, total=False):
    coffeeMaker: bool
    coffeeMakerException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    cookware: bool
    cookwareException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    dishwasher: bool
    dishwasherException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    indoorGrill: bool
    indoorGrillException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    kettle: bool
    kettleException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    kitchenAvailable: bool
    kitchenAvailableException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    microwave: bool
    microwaveException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    minibar: bool
    minibarException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    outdoorGrill: bool
    outdoorGrillException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    oven: bool
    ovenException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    refrigerator: bool
    refrigeratorException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    sink: bool
    sinkException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    snackbar: bool
    snackbarException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    stove: bool
    stoveException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    teaStation: bool
    teaStationException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    toaster: bool
    toasterException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]

@typing.type_check_only
class LivingAreaFeatures(typing_extensions.TypedDict, total=False):
    airConditioning: bool
    airConditioningException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    bathtub: bool
    bathtubException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    bidet: bool
    bidetException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    dryer: bool
    dryerException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    electronicRoomKey: bool
    electronicRoomKeyException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    fireplace: bool
    fireplaceException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    hairdryer: bool
    hairdryerException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    heating: bool
    heatingException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    inunitSafe: bool
    inunitSafeException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    inunitWifiAvailable: bool
    inunitWifiAvailableException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    ironingEquipment: bool
    ironingEquipmentException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    payPerViewMovies: bool
    payPerViewMoviesException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    privateBathroom: bool
    privateBathroomException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    shower: bool
    showerException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    toilet: bool
    toiletException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    tv: bool
    tvCasting: bool
    tvCastingException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    tvException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    tvStreaming: bool
    tvStreamingException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    universalPowerAdapters: bool
    universalPowerAdaptersException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    washer: bool
    washerException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]

@typing.type_check_only
class LivingAreaLayout(typing_extensions.TypedDict, total=False):
    balcony: bool
    balconyException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    livingAreaSqMeters: float
    livingAreaSqMetersException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    loft: bool
    loftException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    nonSmoking: bool
    nonSmokingException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    patio: bool
    patioException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    stairs: bool
    stairsException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]

@typing.type_check_only
class LivingAreaSleeping(typing_extensions.TypedDict, total=False):
    bedsCount: int
    bedsCountException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    bunkBedsCount: int
    bunkBedsCountException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    cribsCount: int
    cribsCountException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    doubleBedsCount: int
    doubleBedsCountException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    featherPillows: bool
    featherPillowsException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    hypoallergenicBedding: bool
    hypoallergenicBeddingException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    kingBedsCount: int
    kingBedsCountException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    memoryFoamPillows: bool
    memoryFoamPillowsException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    otherBedsCount: int
    otherBedsCountException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    queenBedsCount: int
    queenBedsCountException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    rollAwayBedsCount: int
    rollAwayBedsCountException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    singleOrTwinBedsCount: int
    singleOrTwinBedsCountException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    sofaBedsCount: int
    sofaBedsCountException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    syntheticPillows: bool
    syntheticPillowsException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]

@typing.type_check_only
class Lodging(typing_extensions.TypedDict, total=False):
    accessibility: Accessibility
    activities: Activities
    allUnits: GuestUnitFeatures
    business: Business
    commonLivingArea: LivingArea
    connectivity: Connectivity
    families: Families
    foodAndDrink: FoodAndDrink
    guestUnits: _list[GuestUnitType]
    healthAndSafety: HealthAndSafety
    housekeeping: Housekeeping
    metadata: LodgingMetadata
    name: str
    parking: Parking
    pets: Pets
    policies: Policies
    pools: Pools
    property: Property
    services: Services
    someUnits: GuestUnitFeatures
    sustainability: Sustainability
    transportation: Transportation
    wellness: Wellness

@typing.type_check_only
class LodgingMetadata(typing_extensions.TypedDict, total=False):
    updateTime: str

@typing.type_check_only
class MinimizedContact(typing_extensions.TypedDict, total=False):
    contactlessCheckinCheckout: bool
    contactlessCheckinCheckoutException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    digitalGuestRoomKeys: bool
    digitalGuestRoomKeysException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    housekeepingScheduledRequestOnly: bool
    housekeepingScheduledRequestOnlyException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    noHighTouchItemsCommonAreas: bool
    noHighTouchItemsCommonAreasException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    noHighTouchItemsGuestRooms: bool
    noHighTouchItemsGuestRoomsException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    plasticKeycardsDisinfected: bool
    plasticKeycardsDisinfectedException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    roomBookingsBuffer: bool
    roomBookingsBufferException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]

@typing.type_check_only
class Parking(typing_extensions.TypedDict, total=False):
    electricCarChargingStations: bool
    electricCarChargingStationsException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    freeParking: bool
    freeParkingException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    freeSelfParking: bool
    freeSelfParkingException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    freeValetParking: bool
    freeValetParkingException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    parkingAvailable: bool
    parkingAvailableException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    selfParkingAvailable: bool
    selfParkingAvailableException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    valetParkingAvailable: bool
    valetParkingAvailableException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]

@typing.type_check_only
class PaymentOptions(typing_extensions.TypedDict, total=False):
    cash: bool
    cashException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    cheque: bool
    chequeException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    creditCard: bool
    creditCardException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    debitCard: bool
    debitCardException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    mobileNfc: bool
    mobileNfcException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]

@typing.type_check_only
class PersonalProtection(typing_extensions.TypedDict, total=False):
    commonAreasOfferSanitizingItems: bool
    commonAreasOfferSanitizingItemsException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    faceMaskRequired: bool
    faceMaskRequiredException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    guestRoomHygieneKitsAvailable: bool
    guestRoomHygieneKitsAvailableException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    protectiveEquipmentAvailable: bool
    protectiveEquipmentAvailableException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]

@typing.type_check_only
class Pets(typing_extensions.TypedDict, total=False):
    catsAllowed: bool
    catsAllowedException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    dogsAllowed: bool
    dogsAllowedException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    petsAllowed: bool
    petsAllowedException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    petsAllowedFree: bool
    petsAllowedFreeException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]

@typing.type_check_only
class PhysicalDistancing(typing_extensions.TypedDict, total=False):
    commonAreasPhysicalDistancingArranged: bool
    commonAreasPhysicalDistancingArrangedException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    physicalDistancingRequired: bool
    physicalDistancingRequiredException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    safetyDividers: bool
    safetyDividersException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    sharedAreasLimitedOccupancy: bool
    sharedAreasLimitedOccupancyException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    wellnessAreasHavePrivateSpaces: bool
    wellnessAreasHavePrivateSpacesException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]

@typing.type_check_only
class Policies(typing_extensions.TypedDict, total=False):
    allInclusiveAvailable: bool
    allInclusiveAvailableException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    allInclusiveOnly: bool
    allInclusiveOnlyException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    checkinTime: TimeOfDay
    checkinTimeException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    checkoutTime: TimeOfDay
    checkoutTimeException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    kidsStayFree: bool
    kidsStayFreeException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    maxChildAge: int
    maxChildAgeException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    maxKidsStayFreeCount: int
    maxKidsStayFreeCountException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    paymentOptions: PaymentOptions
    smokeFreeProperty: bool
    smokeFreePropertyException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]

@typing.type_check_only
class Pools(typing_extensions.TypedDict, total=False):
    adultPool: bool
    adultPoolException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    hotTub: bool
    hotTubException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    indoorPool: bool
    indoorPoolException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    indoorPoolsCount: int
    indoorPoolsCountException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    lazyRiver: bool
    lazyRiverException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    lifeguard: bool
    lifeguardException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    outdoorPool: bool
    outdoorPoolException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    outdoorPoolsCount: int
    outdoorPoolsCountException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    pool: bool
    poolException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    poolsCount: int
    poolsCountException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    wadingPool: bool
    wadingPoolException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    waterPark: bool
    waterParkException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    waterslide: bool
    waterslideException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    wavePool: bool
    wavePoolException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]

@typing.type_check_only
class Property(typing_extensions.TypedDict, total=False):
    builtYear: int
    builtYearException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    floorsCount: int
    floorsCountException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    lastRenovatedYear: int
    lastRenovatedYearException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    roomsCount: int
    roomsCountException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]

@typing.type_check_only
class Services(typing_extensions.TypedDict, total=False):
    baggageStorage: bool
    baggageStorageException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    concierge: bool
    conciergeException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    convenienceStore: bool
    convenienceStoreException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    currencyExchange: bool
    currencyExchangeException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    elevator: bool
    elevatorException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    frontDesk: bool
    frontDeskException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    fullServiceLaundry: bool
    fullServiceLaundryException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    giftShop: bool
    giftShopException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    languagesSpoken: _list[LanguageSpoken]
    selfServiceLaundry: bool
    selfServiceLaundryException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    socialHour: bool
    socialHourException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    twentyFourHourFrontDesk: bool
    twentyFourHourFrontDeskException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    wakeUpCalls: bool
    wakeUpCallsException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]

@typing.type_check_only
class Sustainability(typing_extensions.TypedDict, total=False):
    energyEfficiency: EnergyEfficiency
    sustainabilityCertifications: SustainabilityCertifications
    sustainableSourcing: SustainableSourcing
    wasteReduction: WasteReduction
    waterConservation: WaterConservation

@typing.type_check_only
class SustainabilityCertifications(typing_extensions.TypedDict, total=False):
    breeamCertification: typing_extensions.Literal[
        "BREEAM_CERTIFICATION_UNSPECIFIED",
        "NO_BREEAM_CERTIFICATION",
        "BREEAM_PASS",
        "BREEAM_GOOD",
        "BREEAM_VERY_GOOD",
        "BREEAM_EXCELLENT",
        "BREEAM_OUTSTANDING",
    ]
    breeamCertificationException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    ecoCertifications: _list[EcoCertification]
    leedCertification: typing_extensions.Literal[
        "LEED_CERTIFICATION_UNSPECIFIED",
        "NO_LEED_CERTIFICATION",
        "LEED_CERTIFIED",
        "LEED_SILVER",
        "LEED_GOLD",
        "LEED_PLATINUM",
    ]
    leedCertificationException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]

@typing.type_check_only
class SustainableSourcing(typing_extensions.TypedDict, total=False):
    ecoFriendlyToiletries: bool
    ecoFriendlyToiletriesException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    locallySourcedFoodAndBeverages: bool
    locallySourcedFoodAndBeveragesException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    organicCageFreeEggs: bool
    organicCageFreeEggsException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    organicFoodAndBeverages: bool
    organicFoodAndBeveragesException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    responsiblePurchasingPolicy: bool
    responsiblePurchasingPolicyException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    responsiblySourcesSeafood: bool
    responsiblySourcesSeafoodException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    veganMeals: bool
    veganMealsException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    vegetarianMeals: bool
    vegetarianMealsException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]

@typing.type_check_only
class TimeOfDay(typing_extensions.TypedDict, total=False):
    hours: int
    minutes: int
    nanos: int
    seconds: int

@typing.type_check_only
class Transportation(typing_extensions.TypedDict, total=False):
    airportShuttle: bool
    airportShuttleException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    carRentalOnProperty: bool
    carRentalOnPropertyException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    freeAirportShuttle: bool
    freeAirportShuttleException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    freePrivateCarService: bool
    freePrivateCarServiceException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    localShuttle: bool
    localShuttleException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    privateCarService: bool
    privateCarServiceException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    transfer: bool
    transferException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]

@typing.type_check_only
class ViewsFromUnit(typing_extensions.TypedDict, total=False):
    beachView: bool
    beachViewException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    cityView: bool
    cityViewException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    gardenView: bool
    gardenViewException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    lakeView: bool
    lakeViewException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    landmarkView: bool
    landmarkViewException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    oceanView: bool
    oceanViewException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    poolView: bool
    poolViewException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    valleyView: bool
    valleyViewException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]

@typing.type_check_only
class WasteReduction(typing_extensions.TypedDict, total=False):
    compostableFoodContainersAndCutlery: bool
    compostableFoodContainersAndCutleryException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    compostsExcessFood: bool
    compostsExcessFoodException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    donatesExcessFood: bool
    donatesExcessFoodException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    foodWasteReductionProgram: bool
    foodWasteReductionProgramException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    noSingleUsePlasticStraws: bool
    noSingleUsePlasticStrawsException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    noSingleUsePlasticWaterBottles: bool
    noSingleUsePlasticWaterBottlesException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    noStyrofoamFoodContainers: bool
    noStyrofoamFoodContainersException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    recyclingProgram: bool
    recyclingProgramException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    refillableToiletryContainers: bool
    refillableToiletryContainersException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    safelyDisposesBatteries: bool
    safelyDisposesBatteriesException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    safelyDisposesElectronics: bool
    safelyDisposesElectronicsException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    safelyDisposesLightbulbs: bool
    safelyDisposesLightbulbsException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    safelyHandlesHazardousSubstances: bool
    safelyHandlesHazardousSubstancesException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    soapDonationProgram: bool
    soapDonationProgramException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    toiletryDonationProgram: bool
    toiletryDonationProgramException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    waterBottleFillingStations: bool
    waterBottleFillingStationsException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]

@typing.type_check_only
class WaterConservation(typing_extensions.TypedDict, total=False):
    independentOrganizationAuditsWaterUse: bool
    independentOrganizationAuditsWaterUseException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    linenReuseProgram: bool
    linenReuseProgramException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    towelReuseProgram: bool
    towelReuseProgramException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    waterSavingShowers: bool
    waterSavingShowersException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    waterSavingSinks: bool
    waterSavingSinksException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    waterSavingToilets: bool
    waterSavingToiletsException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]

@typing.type_check_only
class Wellness(typing_extensions.TypedDict, total=False):
    doctorOnCall: bool
    doctorOnCallException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    ellipticalMachine: bool
    ellipticalMachineException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    fitnessCenter: bool
    fitnessCenterException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    freeFitnessCenter: bool
    freeFitnessCenterException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    freeWeights: bool
    freeWeightsException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    massage: bool
    massageException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    salon: bool
    salonException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    sauna: bool
    saunaException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    spa: bool
    spaException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    treadmill: bool
    treadmillException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]
    weightMachine: bool
    weightMachineException: typing_extensions.Literal[
        "EXCEPTION_UNSPECIFIED",
        "UNDER_CONSTRUCTION",
        "DEPENDENT_ON_SEASON",
        "DEPENDENT_ON_DAY_OF_WEEK",
    ]



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Aggregation(typing_extensions.TypedDict, total=False):
    alias: str
    count: Count

@typing.type_check_only
class AggregationResult(typing_extensions.TypedDict, total=False):
    aggregateFields: dict[str, typing.Any]

@typing.type_check_only
class ArrayValue(typing_extensions.TypedDict, total=False):
    values: _list[Value]

@typing.type_check_only
class BatchGetDocumentsRequest(typing_extensions.TypedDict, total=False):
    documents: _list[str]
    mask: DocumentMask
    newTransaction: TransactionOptions
    readTime: str
    transaction: str

@typing.type_check_only
class BatchGetDocumentsResponse(typing_extensions.TypedDict, total=False):
    found: Document
    missing: str
    readTime: str
    transaction: str

@typing.type_check_only
class BatchWriteRequest(typing_extensions.TypedDict, total=False):
    labels: dict[str, typing.Any]
    writes: _list[Write]

@typing.type_check_only
class BatchWriteResponse(typing_extensions.TypedDict, total=False):
    status: _list[Status]
    writeResults: _list[WriteResult]

@typing.type_check_only
class BeginTransactionRequest(typing_extensions.TypedDict, total=False):
    options: TransactionOptions

@typing.type_check_only
class BeginTransactionResponse(typing_extensions.TypedDict, total=False):
    transaction: str

@typing.type_check_only
class CollectionSelector(typing_extensions.TypedDict, total=False):
    allDescendants: bool
    collectionId: str

@typing.type_check_only
class CommitRequest(typing_extensions.TypedDict, total=False):
    transaction: str
    writes: _list[Write]

@typing.type_check_only
class CommitResponse(typing_extensions.TypedDict, total=False):
    commitTime: str
    writeResults: _list[WriteResult]

@typing.type_check_only
class CompositeFilter(typing_extensions.TypedDict, total=False):
    filters: _list[Filter]
    op: typing_extensions.Literal["OPERATOR_UNSPECIFIED", "AND"]

@typing.type_check_only
class Count(typing_extensions.TypedDict, total=False):
    upTo: str

@typing.type_check_only
class Cursor(typing_extensions.TypedDict, total=False):
    before: bool
    values: _list[Value]

@typing.type_check_only
class Document(typing_extensions.TypedDict, total=False):
    createTime: str
    fields: dict[str, typing.Any]
    name: str
    updateTime: str

@typing.type_check_only
class DocumentChange(typing_extensions.TypedDict, total=False):
    document: Document
    removedTargetIds: _list[int]
    targetIds: _list[int]

@typing.type_check_only
class DocumentDelete(typing_extensions.TypedDict, total=False):
    document: str
    readTime: str
    removedTargetIds: _list[int]

@typing.type_check_only
class DocumentMask(typing_extensions.TypedDict, total=False):
    fieldPaths: _list[str]

@typing.type_check_only
class DocumentRemove(typing_extensions.TypedDict, total=False):
    document: str
    readTime: str
    removedTargetIds: _list[int]

@typing.type_check_only
class DocumentTransform(typing_extensions.TypedDict, total=False):
    document: str
    fieldTransforms: _list[FieldTransform]

@typing.type_check_only
class DocumentsTarget(typing_extensions.TypedDict, total=False):
    documents: _list[str]

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class ExistenceFilter(typing_extensions.TypedDict, total=False):
    count: int
    targetId: int

@typing.type_check_only
class FieldFilter(typing_extensions.TypedDict, total=False):
    field: FieldReference
    op: typing_extensions.Literal[
        "OPERATOR_UNSPECIFIED",
        "LESS_THAN",
        "LESS_THAN_OR_EQUAL",
        "GREATER_THAN",
        "GREATER_THAN_OR_EQUAL",
        "EQUAL",
        "NOT_EQUAL",
        "ARRAY_CONTAINS",
        "IN",
        "ARRAY_CONTAINS_ANY",
        "NOT_IN",
    ]
    value: Value

@typing.type_check_only
class FieldReference(typing_extensions.TypedDict, total=False):
    fieldPath: str

@typing.type_check_only
class FieldTransform(typing_extensions.TypedDict, total=False):
    appendMissingElements: ArrayValue
    fieldPath: str
    increment: Value
    maximum: Value
    minimum: Value
    removeAllFromArray: ArrayValue
    setToServerValue: typing_extensions.Literal[
        "SERVER_VALUE_UNSPECIFIED", "REQUEST_TIME"
    ]

@typing.type_check_only
class Filter(typing_extensions.TypedDict, total=False):
    compositeFilter: CompositeFilter
    fieldFilter: FieldFilter
    unaryFilter: UnaryFilter

@typing.type_check_only
class GoogleFirestoreAdminV1Database(typing_extensions.TypedDict, total=False):
    appEngineIntegrationMode: typing_extensions.Literal[
        "APP_ENGINE_INTEGRATION_MODE_UNSPECIFIED", "ENABLED", "DISABLED"
    ]
    concurrencyMode: typing_extensions.Literal[
        "CONCURRENCY_MODE_UNSPECIFIED",
        "OPTIMISTIC",
        "PESSIMISTIC",
        "OPTIMISTIC_WITH_ENTITY_GROUPS",
    ]
    etag: str
    keyPrefix: str
    locationId: str
    name: str
    type: typing_extensions.Literal[
        "DATABASE_TYPE_UNSPECIFIED", "FIRESTORE_NATIVE", "DATASTORE_MODE"
    ]

@typing.type_check_only
class GoogleFirestoreAdminV1ExportDocumentsMetadata(
    typing_extensions.TypedDict, total=False
):
    collectionIds: _list[str]
    endTime: str
    operationState: typing_extensions.Literal[
        "OPERATION_STATE_UNSPECIFIED",
        "INITIALIZING",
        "PROCESSING",
        "CANCELLING",
        "FINALIZING",
        "SUCCESSFUL",
        "FAILED",
        "CANCELLED",
    ]
    outputUriPrefix: str
    progressBytes: GoogleFirestoreAdminV1Progress
    progressDocuments: GoogleFirestoreAdminV1Progress
    startTime: str

@typing.type_check_only
class GoogleFirestoreAdminV1ExportDocumentsRequest(
    typing_extensions.TypedDict, total=False
):
    collectionIds: _list[str]
    outputUriPrefix: str

@typing.type_check_only
class GoogleFirestoreAdminV1ExportDocumentsResponse(
    typing_extensions.TypedDict, total=False
):
    outputUriPrefix: str

@typing.type_check_only
class GoogleFirestoreAdminV1Field(typing_extensions.TypedDict, total=False):
    indexConfig: GoogleFirestoreAdminV1IndexConfig
    name: str
    ttlConfig: GoogleFirestoreAdminV1TtlConfig

@typing.type_check_only
class GoogleFirestoreAdminV1FieldOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    endTime: str
    field: str
    indexConfigDeltas: _list[GoogleFirestoreAdminV1IndexConfigDelta]
    progressBytes: GoogleFirestoreAdminV1Progress
    progressDocuments: GoogleFirestoreAdminV1Progress
    startTime: str
    state: typing_extensions.Literal[
        "OPERATION_STATE_UNSPECIFIED",
        "INITIALIZING",
        "PROCESSING",
        "CANCELLING",
        "FINALIZING",
        "SUCCESSFUL",
        "FAILED",
        "CANCELLED",
    ]
    ttlConfigDelta: GoogleFirestoreAdminV1TtlConfigDelta

@typing.type_check_only
class GoogleFirestoreAdminV1ImportDocumentsMetadata(
    typing_extensions.TypedDict, total=False
):
    collectionIds: _list[str]
    endTime: str
    inputUriPrefix: str
    operationState: typing_extensions.Literal[
        "OPERATION_STATE_UNSPECIFIED",
        "INITIALIZING",
        "PROCESSING",
        "CANCELLING",
        "FINALIZING",
        "SUCCESSFUL",
        "FAILED",
        "CANCELLED",
    ]
    progressBytes: GoogleFirestoreAdminV1Progress
    progressDocuments: GoogleFirestoreAdminV1Progress
    startTime: str

@typing.type_check_only
class GoogleFirestoreAdminV1ImportDocumentsRequest(
    typing_extensions.TypedDict, total=False
):
    collectionIds: _list[str]
    inputUriPrefix: str

@typing.type_check_only
class GoogleFirestoreAdminV1Index(typing_extensions.TypedDict, total=False):
    fields: _list[GoogleFirestoreAdminV1IndexField]
    name: str
    queryScope: typing_extensions.Literal[
        "QUERY_SCOPE_UNSPECIFIED", "COLLECTION", "COLLECTION_GROUP"
    ]
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "CREATING", "READY", "NEEDS_REPAIR"
    ]

@typing.type_check_only
class GoogleFirestoreAdminV1IndexConfig(typing_extensions.TypedDict, total=False):
    ancestorField: str
    indexes: _list[GoogleFirestoreAdminV1Index]
    reverting: bool
    usesAncestorConfig: bool

@typing.type_check_only
class GoogleFirestoreAdminV1IndexConfigDelta(typing_extensions.TypedDict, total=False):
    changeType: typing_extensions.Literal["CHANGE_TYPE_UNSPECIFIED", "ADD", "REMOVE"]
    index: GoogleFirestoreAdminV1Index

@typing.type_check_only
class GoogleFirestoreAdminV1IndexField(typing_extensions.TypedDict, total=False):
    arrayConfig: typing_extensions.Literal["ARRAY_CONFIG_UNSPECIFIED", "CONTAINS"]
    fieldPath: str
    order: typing_extensions.Literal["ORDER_UNSPECIFIED", "ASCENDING", "DESCENDING"]

@typing.type_check_only
class GoogleFirestoreAdminV1IndexOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    endTime: str
    index: str
    progressBytes: GoogleFirestoreAdminV1Progress
    progressDocuments: GoogleFirestoreAdminV1Progress
    startTime: str
    state: typing_extensions.Literal[
        "OPERATION_STATE_UNSPECIFIED",
        "INITIALIZING",
        "PROCESSING",
        "CANCELLING",
        "FINALIZING",
        "SUCCESSFUL",
        "FAILED",
        "CANCELLED",
    ]

@typing.type_check_only
class GoogleFirestoreAdminV1ListDatabasesResponse(
    typing_extensions.TypedDict, total=False
):
    databases: _list[GoogleFirestoreAdminV1Database]

@typing.type_check_only
class GoogleFirestoreAdminV1ListFieldsResponse(
    typing_extensions.TypedDict, total=False
):
    fields: _list[GoogleFirestoreAdminV1Field]
    nextPageToken: str

@typing.type_check_only
class GoogleFirestoreAdminV1ListIndexesResponse(
    typing_extensions.TypedDict, total=False
):
    indexes: _list[GoogleFirestoreAdminV1Index]
    nextPageToken: str

@typing.type_check_only
class GoogleFirestoreAdminV1LocationMetadata(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleFirestoreAdminV1Progress(typing_extensions.TypedDict, total=False):
    completedWork: str
    estimatedWork: str

@typing.type_check_only
class GoogleFirestoreAdminV1TtlConfig(typing_extensions.TypedDict, total=False):
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "CREATING", "ACTIVE", "NEEDS_REPAIR"
    ]

@typing.type_check_only
class GoogleFirestoreAdminV1TtlConfigDelta(typing_extensions.TypedDict, total=False):
    changeType: typing_extensions.Literal["CHANGE_TYPE_UNSPECIFIED", "ADD", "REMOVE"]

@typing.type_check_only
class GoogleFirestoreAdminV1UpdateDatabaseMetadata(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleLongrunningCancelOperationRequest(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleLongrunningListOperationsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    operations: _list[GoogleLongrunningOperation]

@typing.type_check_only
class GoogleLongrunningOperation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class LatLng(typing_extensions.TypedDict, total=False):
    latitude: float
    longitude: float

@typing.type_check_only
class ListCollectionIdsRequest(typing_extensions.TypedDict, total=False):
    pageSize: int
    pageToken: str
    readTime: str

@typing.type_check_only
class ListCollectionIdsResponse(typing_extensions.TypedDict, total=False):
    collectionIds: _list[str]
    nextPageToken: str

@typing.type_check_only
class ListDocumentsResponse(typing_extensions.TypedDict, total=False):
    documents: _list[Document]
    nextPageToken: str

@typing.type_check_only
class ListLocationsResponse(typing_extensions.TypedDict, total=False):
    locations: _list[Location]
    nextPageToken: str

@typing.type_check_only
class ListenRequest(typing_extensions.TypedDict, total=False):
    addTarget: Target
    labels: dict[str, typing.Any]
    removeTarget: int

@typing.type_check_only
class ListenResponse(typing_extensions.TypedDict, total=False):
    documentChange: DocumentChange
    documentDelete: DocumentDelete
    documentRemove: DocumentRemove
    filter: ExistenceFilter
    targetChange: TargetChange

@typing.type_check_only
class Location(typing_extensions.TypedDict, total=False):
    displayName: str
    labels: dict[str, typing.Any]
    locationId: str
    metadata: dict[str, typing.Any]
    name: str

@typing.type_check_only
class MapValue(typing_extensions.TypedDict, total=False):
    fields: dict[str, typing.Any]

@typing.type_check_only
class Order(typing_extensions.TypedDict, total=False):
    direction: typing_extensions.Literal[
        "DIRECTION_UNSPECIFIED", "ASCENDING", "DESCENDING"
    ]
    field: FieldReference

@typing.type_check_only
class PartitionQueryRequest(typing_extensions.TypedDict, total=False):
    pageSize: int
    pageToken: str
    partitionCount: str
    readTime: str
    structuredQuery: StructuredQuery

@typing.type_check_only
class PartitionQueryResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    partitions: _list[Cursor]

@typing.type_check_only
class Precondition(typing_extensions.TypedDict, total=False):
    exists: bool
    updateTime: str

@typing.type_check_only
class Projection(typing_extensions.TypedDict, total=False):
    fields: _list[FieldReference]

@typing.type_check_only
class QueryTarget(typing_extensions.TypedDict, total=False):
    parent: str
    structuredQuery: StructuredQuery

@typing.type_check_only
class ReadOnly(typing_extensions.TypedDict, total=False):
    readTime: str

@typing.type_check_only
class ReadWrite(typing_extensions.TypedDict, total=False):
    retryTransaction: str

@typing.type_check_only
class RollbackRequest(typing_extensions.TypedDict, total=False):
    transaction: str

@typing.type_check_only
class RunAggregationQueryRequest(typing_extensions.TypedDict, total=False):
    newTransaction: TransactionOptions
    readTime: str
    structuredAggregationQuery: StructuredAggregationQuery
    transaction: str

@typing.type_check_only
class RunAggregationQueryResponse(typing_extensions.TypedDict, total=False):
    readTime: str
    result: AggregationResult
    transaction: str

@typing.type_check_only
class RunQueryRequest(typing_extensions.TypedDict, total=False):
    newTransaction: TransactionOptions
    readTime: str
    structuredQuery: StructuredQuery
    transaction: str

@typing.type_check_only
class RunQueryResponse(typing_extensions.TypedDict, total=False):
    document: Document
    done: bool
    readTime: str
    skippedResults: int
    transaction: str

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class StructuredAggregationQuery(typing_extensions.TypedDict, total=False):
    aggregations: _list[Aggregation]
    structuredQuery: StructuredQuery

AlternativeStructuredQuery = typing_extensions.TypedDict(
    "AlternativeStructuredQuery",
    {
        "endAt": Cursor,
        "from": _list[CollectionSelector],
        "limit": int,
        "offset": int,
        "orderBy": _list[Order],
        "select": Projection,
        "startAt": Cursor,
        "where": Filter,
    },
    total=False,
)

@typing.type_check_only
class StructuredQuery(AlternativeStructuredQuery): ...

@typing.type_check_only
class Target(typing_extensions.TypedDict, total=False):
    documents: DocumentsTarget
    once: bool
    query: QueryTarget
    readTime: str
    resumeToken: str
    targetId: int

@typing.type_check_only
class TargetChange(typing_extensions.TypedDict, total=False):
    cause: Status
    readTime: str
    resumeToken: str
    targetChangeType: typing_extensions.Literal[
        "NO_CHANGE", "ADD", "REMOVE", "CURRENT", "RESET"
    ]
    targetIds: _list[int]

@typing.type_check_only
class TransactionOptions(typing_extensions.TypedDict, total=False):
    readOnly: ReadOnly
    readWrite: ReadWrite

@typing.type_check_only
class UnaryFilter(typing_extensions.TypedDict, total=False):
    field: FieldReference
    op: typing_extensions.Literal[
        "OPERATOR_UNSPECIFIED", "IS_NAN", "IS_NULL", "IS_NOT_NAN", "IS_NOT_NULL"
    ]

@typing.type_check_only
class Value(typing_extensions.TypedDict, total=False):
    arrayValue: ArrayValue
    booleanValue: bool
    bytesValue: str
    doubleValue: float
    geoPointValue: LatLng
    integerValue: str
    mapValue: MapValue
    nullValue: typing_extensions.Literal["NULL_VALUE"]
    referenceValue: str
    stringValue: str
    timestampValue: str

@typing.type_check_only
class Write(typing_extensions.TypedDict, total=False):
    currentDocument: Precondition
    delete: str
    transform: DocumentTransform
    update: Document
    updateMask: DocumentMask
    updateTransforms: _list[FieldTransform]

@typing.type_check_only
class WriteRequest(typing_extensions.TypedDict, total=False):
    labels: dict[str, typing.Any]
    streamId: str
    streamToken: str
    writes: _list[Write]

@typing.type_check_only
class WriteResponse(typing_extensions.TypedDict, total=False):
    commitTime: str
    streamId: str
    streamToken: str
    writeResults: _list[WriteResult]

@typing.type_check_only
class WriteResult(typing_extensions.TypedDict, total=False):
    transformResults: _list[Value]
    updateTime: str



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AuditConfig(typing_extensions.TypedDict, total=False):
    auditLogConfigs: _list[AuditLogConfig]
    service: str

@typing.type_check_only
class AuditLogConfig(typing_extensions.TypedDict, total=False):
    exemptedMembers: _list[str]
    logType: typing_extensions.Literal[
        "LOG_TYPE_UNSPECIFIED", "ADMIN_READ", "DATA_WRITE", "DATA_READ"
    ]

@typing.type_check_only
class Binding(typing_extensions.TypedDict, total=False):
    condition: Expr
    members: _list[str]
    role: str

@typing.type_check_only
class BuildConfig(typing_extensions.TypedDict, total=False):
    build: str
    dockerRepository: str
    entryPoint: str
    environmentVariables: dict[str, typing.Any]
    runtime: str
    source: Source
    sourceProvenance: SourceProvenance
    workerPool: str

@typing.type_check_only
class EventFilter(typing_extensions.TypedDict, total=False):
    attribute: str
    operator: str
    value: str

@typing.type_check_only
class EventTrigger(typing_extensions.TypedDict, total=False):
    channel: str
    eventFilters: _list[EventFilter]
    eventType: str
    pubsubTopic: str
    retryPolicy: typing_extensions.Literal[
        "RETRY_POLICY_UNSPECIFIED", "RETRY_POLICY_DO_NOT_RETRY", "RETRY_POLICY_RETRY"
    ]
    serviceAccountEmail: str
    trigger: str
    triggerRegion: str

@typing.type_check_only
class Expr(typing_extensions.TypedDict, total=False):
    description: str
    expression: str
    location: str
    title: str

@typing.type_check_only
class Function(typing_extensions.TypedDict, total=False):
    buildConfig: BuildConfig
    description: str
    environment: typing_extensions.Literal["ENVIRONMENT_UNSPECIFIED", "GEN_1", "GEN_2"]
    eventTrigger: EventTrigger
    labels: dict[str, typing.Any]
    name: str
    serviceConfig: ServiceConfig
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "ACTIVE", "FAILED", "DEPLOYING", "DELETING", "UNKNOWN"
    ]
    stateMessages: _list[GoogleCloudFunctionsV2alphaStateMessage]
    updateTime: str

@typing.type_check_only
class GenerateDownloadUrlRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class GenerateDownloadUrlResponse(typing_extensions.TypedDict, total=False):
    downloadUrl: str

@typing.type_check_only
class GenerateUploadUrlRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class GenerateUploadUrlResponse(typing_extensions.TypedDict, total=False):
    storageSource: StorageSource
    uploadUrl: str

@typing.type_check_only
class GoogleCloudFunctionsV2OperationMetadata(typing_extensions.TypedDict, total=False):
    apiVersion: str
    cancelRequested: bool
    createTime: str
    endTime: str
    requestResource: dict[str, typing.Any]
    stages: _list[GoogleCloudFunctionsV2Stage]
    statusDetail: str
    target: str
    verb: str

@typing.type_check_only
class GoogleCloudFunctionsV2Stage(typing_extensions.TypedDict, total=False):
    message: str
    name: typing_extensions.Literal[
        "NAME_UNSPECIFIED",
        "ARTIFACT_REGISTRY",
        "BUILD",
        "SERVICE",
        "TRIGGER",
        "SERVICE_ROLLBACK",
        "TRIGGER_ROLLBACK",
    ]
    resource: str
    resourceUri: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "NOT_STARTED", "IN_PROGRESS", "COMPLETE"
    ]
    stateMessages: _list[GoogleCloudFunctionsV2StateMessage]

@typing.type_check_only
class GoogleCloudFunctionsV2StateMessage(typing_extensions.TypedDict, total=False):
    message: str
    severity: typing_extensions.Literal[
        "SEVERITY_UNSPECIFIED", "ERROR", "WARNING", "INFO"
    ]
    type: str

@typing.type_check_only
class GoogleCloudFunctionsV2alphaOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    apiVersion: str
    cancelRequested: bool
    createTime: str
    endTime: str
    requestResource: dict[str, typing.Any]
    stages: _list[GoogleCloudFunctionsV2alphaStage]
    statusDetail: str
    target: str
    verb: str

@typing.type_check_only
class GoogleCloudFunctionsV2alphaStage(typing_extensions.TypedDict, total=False):
    message: str
    name: typing_extensions.Literal[
        "NAME_UNSPECIFIED",
        "ARTIFACT_REGISTRY",
        "BUILD",
        "SERVICE",
        "TRIGGER",
        "SERVICE_ROLLBACK",
        "TRIGGER_ROLLBACK",
    ]
    resource: str
    resourceUri: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "NOT_STARTED", "IN_PROGRESS", "COMPLETE"
    ]
    stateMessages: _list[GoogleCloudFunctionsV2alphaStateMessage]

@typing.type_check_only
class GoogleCloudFunctionsV2alphaStateMessage(typing_extensions.TypedDict, total=False):
    message: str
    severity: typing_extensions.Literal[
        "SEVERITY_UNSPECIFIED", "ERROR", "WARNING", "INFO"
    ]
    type: str

@typing.type_check_only
class GoogleCloudFunctionsV2betaOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    apiVersion: str
    cancelRequested: bool
    createTime: str
    endTime: str
    requestResource: dict[str, typing.Any]
    stages: _list[GoogleCloudFunctionsV2betaStage]
    statusDetail: str
    target: str
    verb: str

@typing.type_check_only
class GoogleCloudFunctionsV2betaStage(typing_extensions.TypedDict, total=False):
    message: str
    name: typing_extensions.Literal[
        "NAME_UNSPECIFIED",
        "ARTIFACT_REGISTRY",
        "BUILD",
        "SERVICE",
        "TRIGGER",
        "SERVICE_ROLLBACK",
        "TRIGGER_ROLLBACK",
    ]
    resource: str
    resourceUri: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "NOT_STARTED", "IN_PROGRESS", "COMPLETE"
    ]
    stateMessages: _list[GoogleCloudFunctionsV2betaStateMessage]

@typing.type_check_only
class GoogleCloudFunctionsV2betaStateMessage(typing_extensions.TypedDict, total=False):
    message: str
    severity: typing_extensions.Literal[
        "SEVERITY_UNSPECIFIED", "ERROR", "WARNING", "INFO"
    ]
    type: str

@typing.type_check_only
class ListFunctionsResponse(typing_extensions.TypedDict, total=False):
    functions: _list[Function]
    nextPageToken: str
    unreachable: _list[str]

@typing.type_check_only
class ListLocationsResponse(typing_extensions.TypedDict, total=False):
    locations: _list[Location]
    nextPageToken: str

@typing.type_check_only
class ListOperationsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    operations: _list[Operation]

@typing.type_check_only
class ListRuntimesResponse(typing_extensions.TypedDict, total=False):
    runtimes: _list[Runtime]

@typing.type_check_only
class Location(typing_extensions.TypedDict, total=False):
    displayName: str
    labels: dict[str, typing.Any]
    locationId: str
    metadata: dict[str, typing.Any]
    name: str

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class OperationMetadataV1(typing_extensions.TypedDict, total=False):
    buildId: str
    buildName: str
    request: dict[str, typing.Any]
    sourceToken: str
    target: str
    type: typing_extensions.Literal[
        "OPERATION_UNSPECIFIED", "CREATE_FUNCTION", "UPDATE_FUNCTION", "DELETE_FUNCTION"
    ]
    updateTime: str
    versionId: str

@typing.type_check_only
class Policy(typing_extensions.TypedDict, total=False):
    auditConfigs: _list[AuditConfig]
    bindings: _list[Binding]
    etag: str
    version: int

@typing.type_check_only
class RepoSource(typing_extensions.TypedDict, total=False):
    branchName: str
    commitSha: str
    dir: str
    invertRegex: bool
    projectId: str
    repoName: str
    tagName: str

@typing.type_check_only
class Runtime(typing_extensions.TypedDict, total=False):
    displayName: str
    environment: typing_extensions.Literal["ENVIRONMENT_UNSPECIFIED", "GEN_1", "GEN_2"]
    name: str
    stage: typing_extensions.Literal[
        "RUNTIME_STAGE_UNSPECIFIED",
        "DEVELOPMENT",
        "ALPHA",
        "BETA",
        "GA",
        "DEPRECATED",
        "DECOMMISSIONED",
    ]
    warnings: _list[str]

@typing.type_check_only
class SecretEnvVar(typing_extensions.TypedDict, total=False):
    key: str
    projectId: str
    secret: str
    version: str

@typing.type_check_only
class SecretVersion(typing_extensions.TypedDict, total=False):
    path: str
    version: str

@typing.type_check_only
class SecretVolume(typing_extensions.TypedDict, total=False):
    mountPath: str
    projectId: str
    secret: str
    versions: _list[SecretVersion]

@typing.type_check_only
class ServiceConfig(typing_extensions.TypedDict, total=False):
    allTrafficOnLatestRevision: bool
    availableMemory: str
    environmentVariables: dict[str, typing.Any]
    ingressSettings: typing_extensions.Literal[
        "INGRESS_SETTINGS_UNSPECIFIED",
        "ALLOW_ALL",
        "ALLOW_INTERNAL_ONLY",
        "ALLOW_INTERNAL_AND_GCLB",
    ]
    maxInstanceCount: int
    minInstanceCount: int
    revision: str
    secretEnvironmentVariables: _list[SecretEnvVar]
    secretVolumes: _list[SecretVolume]
    service: str
    serviceAccountEmail: str
    timeoutSeconds: int
    uri: str
    vpcConnector: str
    vpcConnectorEgressSettings: typing_extensions.Literal[
        "VPC_CONNECTOR_EGRESS_SETTINGS_UNSPECIFIED",
        "PRIVATE_RANGES_ONLY",
        "ALL_TRAFFIC",
    ]

@typing.type_check_only
class SetIamPolicyRequest(typing_extensions.TypedDict, total=False):
    policy: Policy
    updateMask: str

@typing.type_check_only
class Source(typing_extensions.TypedDict, total=False):
    repoSource: RepoSource
    storageSource: StorageSource

@typing.type_check_only
class SourceProvenance(typing_extensions.TypedDict, total=False):
    resolvedRepoSource: RepoSource
    resolvedStorageSource: StorageSource

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class StorageSource(typing_extensions.TypedDict, total=False):
    bucket: str
    generation: str
    object: str

@typing.type_check_only
class TestIamPermissionsRequest(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class TestIamPermissionsResponse(typing_extensions.TypedDict, total=False):
    permissions: _list[str]
